@@ -205,10 +205,10 @@ class S3FileSystem(AsyncFileSystem):
     default_fill_cache : Bool (True)
         Whether to use cache filling with open by default. Refer to
         ``S3File.open``.
-    default_cache_type : string ('bytes')
+    default_cache_type : string ("readahead")
         If given, the default cache_type value used for ``open()``. Set to "none"
         if no caching is desired. See fsspec's documentation for other available
-        cache_type values. Default cache_type is 'bytes'.
+        cache_type values. Default cache_type is "readahead".
     version_aware : bool (False)
         Whether to support bucket versioning.  If enable this will require the
         user to have the necessary IAM permissions for dealing with versioned
@@ -265,7 +265,7 @@ class S3FileSystem(AsyncFileSystem):
         requester_pays=False,
         default_block_size=None,
         default_fill_cache=True,
-        default_cache_type="bytes",
+        default_cache_type="readahead",
         version_aware=False,
         config_kwargs=None,
         s3_additional_kwargs=None,
@@ -377,20 +377,29 @@ class S3FileSystem(AsyncFileSystem):
         It will return the bucket and the key represented by the s3 path
         """
 
-        _S3_ACCESSPOINT_TO_BUCKET_KEY_REGEX = re.compile(
-            r"^(?P<bucket>arn:(aws).*:s3:[a-z\-0-9]*:[0-9]{12}:accesspoint[:/][^/]+)/?"
-            r"(?P<key>.*)$"
-        )
-        _S3_OUTPOST_TO_BUCKET_KEY_REGEX = re.compile(
-            r"^(?P<bucket>arn:(aws).*:s3-outposts:[a-z\-0-9]+:[0-9]{12}:outpost[/:]"
-            r"[a-zA-Z0-9\-]{1,63}[/:](bucket|accesspoint)[/:][a-zA-Z0-9\-]{1,63})[/:]?(?P<key>.*)$"
-        )
-        match = _S3_ACCESSPOINT_TO_BUCKET_KEY_REGEX.match(s3_path)
-        if match:
-            return match.group("bucket"), match.group("key")
-        match = _S3_OUTPOST_TO_BUCKET_KEY_REGEX.match(s3_path)
-        if match:
-            return match.group("bucket"), match.group("key")
+        bucket_format_list = [
+            re.compile(
+                r"^(?P<bucket>arn:(aws).*:s3:[a-z\-0-9]*:[0-9]{12}:accesspoint[:/][^/]+)/?"
+                r"(?P<key>.*)$"
+            ),
+            re.compile(
+                r"^(?P<bucket>arn:(aws).*:s3-outposts:[a-z\-0-9]+:[0-9]{12}:outpost[/:]"
+                r"[a-zA-Z0-9\-]{1,63}[/:](bucket|accesspoint)[/:][a-zA-Z0-9\-]{1,63})[/:]?(?P<key>.*)$"
+            ),
+            re.compile(
+                r"^(?P<bucket>arn:(aws).*:s3-outposts:[a-z\-0-9]+:[0-9]{12}:outpost[/:]"
+                r"[a-zA-Z0-9\-]{1,63}[/:]bucket[/:]"
+                r"[a-zA-Z0-9\-]{1,63})[/:]?(?P<key>.*)$"
+            ),
+            re.compile(
+                r"^(?P<bucket>arn:(aws).*:s3-object-lambda:[a-z\-0-9]+:[0-9]{12}:"
+                r"accesspoint[/:][a-zA-Z0-9\-]{1,63})[/:]?(?P<key>.*)$"
+            ),
+        ]
+        for bucket_format in bucket_format_list:
+            match = bucket_format.match(s3_path)
+            if match:
+                return match.group("bucket"), match.group("key")
         s3_components = s3_path.split("/", 1)
         bucket = s3_components[0]
         s3_key = ""
@@ -661,11 +670,6 @@ class S3FileSystem(AsyncFileSystem):
         prefix="",
         versions=False,
     ):
-        if versions and not self.version_aware:
-            raise ValueError(
-                "versions cannot be specified if the filesystem is not version aware"
-            )
-
         bucket, key, _ = self.split_path(path)
         if not prefix:
             prefix = ""
@@ -674,53 +678,20 @@ class S3FileSystem(AsyncFileSystem):
         if path not in self.dircache or refresh or not delimiter or versions:
             try:
                 logger.debug("Get directory listing page for %s" % path)
-                await self.set_session()
-                s3 = await self.get_s3(bucket)
-                if self.version_aware:
-                    method = "list_object_versions"
-                    contents_key = "Versions"
-                else:
-                    method = "list_objects_v2"
-                    contents_key = "Contents"
-                pag = s3.get_paginator(method)
-                config = {}
-                if max_items is not None:
-                    config.update(MaxItems=max_items, PageSize=2 * max_items)
-                it = pag.paginate(
-                    Bucket=bucket,
-                    Prefix=prefix,
-                    Delimiter=delimiter,
-                    PaginationConfig=config,
-                    **self.req_kw,
-                )
+                dirs = []
                 files = []
-                dircache = []
-                async for i in it:
-                    dircache.extend(i.get("CommonPrefixes", []))
-                    for c in i.get(contents_key, []):
-                        if not self.version_aware or c.get("IsLatest") or versions:
-                            c["type"] = "file"
-                            c["size"] = c["Size"]
-                            files.append(c)
-                if dircache:
-                    files.extend(
-                        [
-                            {
-                                "Key": l["Prefix"][:-1],
-                                "Size": 0,
-                                "StorageClass": "DIRECTORY",
-                                "type": "directory",
-                                "size": 0,
-                            }
-                            for l in dircache
-                        ]
-                    )
-                for f in files:
-                    f["Key"] = "/".join([bucket, f["Key"]])
-                    f["name"] = f["Key"]
-                    version_id = f.get("VersionId")
-                    if versions and version_id and version_id != "null":
-                        f["name"] += f"?versionId={version_id}"
+                async for c in self._iterdir(
+                    bucket,
+                    max_items=max_items,
+                    delimiter=delimiter,
+                    prefix=prefix,
+                    versions=versions,
+                ):
+                    if c["type"] == "directory":
+                        dirs.append(c)
+                    else:
+                        files.append(c)
+                files += dirs
             except ClientError as e:
                 raise translate_boto_error(e)
 
@@ -729,6 +700,62 @@ class S3FileSystem(AsyncFileSystem):
             return files
         return self.dircache[path]
 
+    async def _iterdir(
+        self, bucket, max_items=None, delimiter="/", prefix="", versions=False
+    ):
+        """Iterate asynchronously over files and directories under `prefix`.
+
+        The contents are yielded in arbitrary order as info dicts.
+        """
+        if versions and not self.version_aware:
+            raise ValueError(
+                "versions cannot be specified if the filesystem is not version aware"
+            )
+        await self.set_session()
+        s3 = await self.get_s3(bucket)
+        if self.version_aware:
+            method = "list_object_versions"
+            contents_key = "Versions"
+        else:
+            method = "list_objects_v2"
+            contents_key = "Contents"
+        pag = s3.get_paginator(method)
+        config = {}
+        if max_items is not None:
+            config.update(MaxItems=max_items, PageSize=2 * max_items)
+        it = pag.paginate(
+            Bucket=bucket,
+            Prefix=prefix,
+            Delimiter=delimiter,
+            PaginationConfig=config,
+            **self.req_kw,
+        )
+        async for i in it:
+            for l in i.get("CommonPrefixes", []):
+                c = {
+                    "Key": l["Prefix"][:-1],
+                    "Size": 0,
+                    "StorageClass": "DIRECTORY",
+                    "type": "directory",
+                }
+                self._fill_info(c, bucket, versions=False)
+                yield c
+            for c in i.get(contents_key, []):
+                if not self.version_aware or c.get("IsLatest") or versions:
+                    c["type"] = "file"
+                    c["size"] = c["Size"]
+                    self._fill_info(c, bucket, versions=versions)
+                    yield c
+
+    @staticmethod
+    def _fill_info(f, bucket, versions=False):
+        f["size"] = f["Size"]
+        f["Key"] = "/".join([bucket, f["Key"]])
+        f["name"] = f["Key"]
+        version_id = f.get("VersionId")
+        if versions and version_id and version_id != "null":
+            f["name"] += f"?versionId={version_id}"
+
     async def _glob(self, path, **kwargs):
         if path.startswith("*"):
             raise ValueError("Cannot traverse all of S3")
@@ -737,6 +764,7 @@ class S3FileSystem(AsyncFileSystem):
     async def _find(self, path, maxdepth=None, withdirs=None, detail=False, prefix=""):
         """List all files below path.
         Like posix ``find`` command without conditions
+
         Parameters
         ----------
         path : str
@@ -1508,7 +1536,7 @@ class S3FileSystem(AsyncFileSystem):
 
     setxattr = sync_wrapper(_setxattr)
 
-    async def _chmod(self, path, acl, **kwargs):
+    async def _chmod(self, path, acl, recursive=False, **kwargs):
         """Set Access Control on a bucket/key
 
         See http://docs.aws.amazon.com/AmazonS3/latest/dev/acl-overview.html#canned-acl
@@ -1519,9 +1547,16 @@ class S3FileSystem(AsyncFileSystem):
             the object to set
         acl : string
             the value of ACL to apply
+        recursive : bool
+            whether to apply the ACL to all keys below the given path too
         """
         bucket, key, version_id = self.split_path(path)
-        if key:
+        if recursive:
+            allfiles = await self._find(path, withdirs=False)
+            await asyncio.gather(
+                *[self._chmod(p, acl, recursive=False) for p in allfiles]
+            )
+        elif key:
             if acl not in key_acls:
                 raise ValueError("ACL not in %s", key_acls)
             await self._call_s3(
@@ -1532,7 +1567,7 @@ class S3FileSystem(AsyncFileSystem):
                 ACL=acl,
                 **version_id_kw(version_id),
             )
-        else:
+        if not key:
             if acl not in buck_acls:
                 raise ValueError("ACL not in %s", buck_acls)
             await self._call_s3("put_bucket_acl", kwargs, Bucket=bucket, ACL=acl)
@@ -1953,7 +1988,7 @@ class S3File(AbstractBufferedFile):
         fill_cache=True,
         s3_additional_kwargs=None,
         autocommit=True,
-        cache_type="bytes",
+        cache_type="readahead",
         requester_pays=False,
         cache_options=None,
     ):
